# SSJ**SSJ** é um servidor simples de gestão de dados em arquivos JSON ou um gerenciador de dados em JSON.# Funções* `lock()` - Trava o servidor para todos os clients.* `unlock()` - Destrava o servidor para clients.* `recover_backup()` - Recupera backup enviado para o Dropbox.* `backup()` - Faz backup do JSON criptografado para o Dropbox.* `update_infodb(valor_atualizar, just_append=False, path_dir_=None, antiblock=False)` - Atualiza uma informação no JSON aninhado com base em um path.* `inicia_localdb(path_db_local_local, key_local_db_db=b'', token_drop_local='')` - Inicia o banco de dados para a máquina local, sem disponibilizar em rede local.* `inicia_client(ip_to_connect, port_to_connect, key_to_verify)` - Inicia e conecta um cliente ao host.* `inicia_host(path_db_local_local, ip_to_connect, port_to_connect, key_local_db_db=b'', token_drop_local='')` - Inicia um host na rede local disponibilizando acesso ao banco de dados JSON.* `inicia_manutencao(ip_to_connect, port_to_connect, key_local_db_db=b'')` - Inicia conexão como se fosse um client, porém com privilégios superiores.* `close_server()` - Fecha e desativa o servidor.* `close(travar=False)` - fecha e criptografa o servidor com base em uma key.* `dirfdb(searchdb=None, antiblock=False, path_dir_=None)` - Retorna um dict com todas as informações salvas do banco de dados.* `salva_infodb(data_db_tiny, antiblock=False)` - Salva um dict ao banco de dados, porém substitúi todas as informações salvas.* `cdadd(path_to_update, replace_all_path=False, path_dir_=None)` - Adiciona um ou mais valores ao path de alteração do banco de dados.* `remove_infodb(path_delete=None, path_dir_=None, antiblock=False)` - Apaga um nó de informação do banco de dados com base no path de alteração.* `formata_db(antiblock=False)` - Apaga todas as informações salvas no banco de dados.* `pwdb(path_dir_=None)` - Retorna uma string com o path de alteração atual.* `cdmin(qntd_min=1, path_dir_=None)` - Apaga o último ou mais item do path de alteração.* `dirfdbp()` - Parecido com o dirfdb(), porém retorna as informações de forma estruturada para melhor visualização.